@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 907 2007-07-18 14:13:55Z hikarin $
+# $Id: BBS.pm 955 2007-08-05 15:15:13Z hikarin $
 #
 
 package Img0ch::App::BBS;
@@ -436,7 +436,6 @@ sub is_writeable {
             ip           => $iApp->{_ip_int},
             len          => length $iApp->{__param_MESSAGE},
             samba_close  => $samba,
-            samba_count  => ( $iConfig->get_int('SambaCount') || 30 ),
             samba_ok     => $iCap->can_post_sambaless(),
             samba_wait   => ( $iConfig->get_int('SambaWait') || 3600 ),
             serial       => $iApp->{_serial},
@@ -451,7 +450,7 @@ sub is_writeable {
             %{ $iApp->{__error_args} } = (
                 WAIT    => $args->{samba_rest},
                 SAMBA   => $args->{samba_count},
-                SAMBATM => $args->{samba_rest},
+                SAMBATM => $samba,
             );
             return 0;
         }
