@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Read.pm 474 2007-04-10 13:18:49Z hikarin $
+# $Id: Read.pm 850 2007-06-23 11:39:18Z hikarin $
 #
 
 package Img0ch::App::Read;
@@ -110,12 +110,6 @@ sub init {
     $iApp->{_bbs} = $iBBS;
 
     my $key = $iApp->{_param_key};
-    if ( !$iConfig->get( $option->{disable} ) ) {
-        require Img0ch::Plugin;
-        my $iPlugin = Img0ch::Plugin->new( $iBBS, $key );
-        $iPlugin->do( $option->{type}, $iApp ) or return 0;
-        $iApp->{_plugin} = $iPlugin;
-    }
 
     require Img0ch::Setting;
     my $iSetting = Img0ch::Setting->new($iBBS);
@@ -133,6 +127,13 @@ sub init {
     $iApp->{__thread_count} = $count;
     $iApp->_normalize($mobile);
 
+    if ( !$iConfig->get( $option->{disable} ) ) {
+        require Img0ch::Plugin;
+        my $iPlugin = Img0ch::Plugin->new( $iBBS, $key );
+        $iPlugin->do( $option->{type}, $iApp ) or return 0;
+        $iApp->{_plugin} = $iPlugin;
+    }
+
     1;
 }
 
@@ -165,8 +166,9 @@ sub load_thread {
     my $iThread  = $iApp->{_thread};
 
     my $mobile = $option->{mobile};
-    $iThread->enable_xhtml_break(
-        ( !$mobile and $iConfig->get('EnableXHTMLBreak') ) ? 1 : 0 );
+    if ( !$mobile and $iConfig->get('EnableXHTMLBreak') ) {
+        $iThread->enable_xhtml_break();
+    }
 
     require Img0ch::Plugin;
     my $iPlugin = $iApp->{_plugin} || Img0ch::Plugin->new( $iBBS, $key );
@@ -176,22 +178,23 @@ sub load_thread {
     my $raw               = $iApp->{_param_raw};
     my $count             = $iApp->{__thread_count};
     my $loop              = int( $count / 100 ) + 1;
-    my $omit              = $iConfig->get('OmitDefaultNoName');
+    my $omit              = $option->{noname};
     my $noname            = $iSetting->get('BBS_NONAME_NAME');
 
     my $st        = $iApp->{__read_from};
     my $to        = $iApp->{__read_to};
     my $br2nl     = $option->{br2nl};
     my $parameter = {
+        %$option,
         line    => $iApp->get_param_int('LINE'),
         nofirst => $iApp->{_param_nofirst},
         single  => $iApp->{_param_single},
         raw     => $raw,
-        br2nl   => $br2nl,
     };
 
-    my $max   = $iSetting->get_int('BBS_RES_MAX')
-         || $iConfig->get_int('ResMAX') || 1000;
+    my $max = $iSetting->get_int('BBS_RES_MAX')
+        || $iConfig->get_int('ResMAX')
+        || 1000;
 
     if (    !$iApp->{_param_nofirst}
         and !$iApp->{_param_single}
@@ -284,8 +287,8 @@ sub load_thread {
         'R95'    => $r95,
         'R100'   => $r100,
         'Banner' => $mobile
-        ? $iMeta->main_banner()
-        : $iMeta->mobile_banner(),
+        ? $iMeta->mobile_banner()
+        : $iMeta->main_banner(),
         'DatKByteSize' => int( $iThread->size() / 1024 ),
         'KEY'          => $key,
         'key'          => $key,
@@ -327,82 +330,73 @@ sub redirect_error {
     my $iConfig  = $iApp->{_config};
     my $iKernel  = $iApp->{_kernel};
     my $iRequest = $iApp->{_request};
-
-    require Img0ch::Error;
-    my $key = $iApp->{_param_key} || $iRequest->key;
-    my $iError = Img0ch::Error->new( $iKernel, $key, $iRequest->ip_int() );
-    my $long = $iError->get( $iApp->{__error} || 'INVALID_POST' );
-    $iError->record();
-
-    my $bbs = $iBBS ? $iBBS->get_name() : '';
-    my $server = $iRequest->get_app_uri();
+    my $key      = $iApp->{_param_key} || $iRequest->key;
+    my $bbs      = $iBBS ? $iBBS->get_name() : '';
+    my $server   = $iRequest->get_app_uri();
     my $renderer = $iConfig->get('Renderer') || 'read.cgi';
-    my $reader = join( '/', $server, $renderer, $bbs, $iApp->{_param_key} );
+    my $reader   = join( '/', $server, $renderer, $bbs, $iApp->{_param_key} );
     my $archive_path  = '';
     my $archive_found = 0;
     my $banner        = '';
     my $dat_bytes     = 0;
     my $is_error      = 0;
+    my $long          = '';
     my $meta          = '';
     my $pool_found    = 0;
     my $res_count     = 0;
     my $res_stack     = [];
     my $subject       = '';
+
     if ($iBBS) {
-        $archive_path = $iBBS->path('kako');
+        $archive_path = $iBBS->url('kako');
         require Img0ch::Archive;
         my $iArchive = Img0ch::Archive->new($iBBS);
-        ( $subject, $res_count ) = $iArchive->get($key);
+        ( $subject, $res_count ) = @{ $iArchive->get($key) };
+        $res_count and $archive_found = 1;
+
+        require Img0ch::Pool::Subject;
+        my $iPSubject = Img0ch::Pool::Subject->new($iBBS);
+        ( $subject, $res_count ) = @{ $iPSubject->get($key) };
         if ($res_count) {
-            $archive_found = 1;
-        }
-        else {
-            require Img0ch::Pool::Subject;
-            my $iPSubject = Img0ch::Pool::Subject->new($iBBS);
-            ( $subject, $res_count ) = @{ $iPSubject->get($key) };
-            if ($res_count) {
-                require Img0ch::Pool::Thread;
-                my $iPThread = Img0ch::Pool::Thread->new( $iBBS, $key );
-                $iPThread->load();
-                my @load_reses = (1);
-                $res_count != 1 and push @load_reses, $res_count;
-                for my $i (@load_reses) {
-                    my $res  = $iPThread->get($i);
-                    my $id   = $res->[3];
-                    my $date = $id ? ( join ' ', $res->[2], $id ) : $res->[2];
-                    my $text = $res->[4];
-                    push @{$res_stack},
-                        {
-                        num     => $i,
-                        resno   => $i,
-                        name    => $res->[0],
-                        mail    => $res->[1],
-                        date    => $date,
-                        text    => $text,
-                        isFirst => ( $i == 1 ? 1 : 0 ),
-                        };
-                }
-                $dat_bytes  = $iPThread->size();
-                $pool_found = 1;
+            require Img0ch::Pool::Thread;
+            my $iPThread = Img0ch::Pool::Thread->new( $iBBS, $key );
+            $iPThread->load();
+            my @load_reses = (1);
+            $res_count != 1 and push @load_reses, $res_count;
+            for my $i (@load_reses) {
+                my $res  = $iPThread->get($i);
+                my $id   = $res->[3];
+                my $date = $id ? ( join ' ', $res->[2], $id ) : $res->[2];
+                my $text = $res->[4];
+                push @{$res_stack},
+                    {
+                    num     => $i,
+                    resno   => $i,
+                    name    => $res->[0],
+                    mail    => $res->[1],
+                    date    => $date,
+                    text    => $text,
+                    isFirst => ( $i == 1 ? 1 : 0 ),
+                    };
             }
+            $dat_bytes  = $iPThread->size();
+            $pool_found = 1;
         }
+
         require Img0ch::Metadata;
         my $iMeta = Img0ch::Metadata->new($iBBS);
         $banner = $iMeta->main_banner();
         $meta   = $iMeta->meta();
     }
     else {
+        require Img0ch::Error;
+        my $ip = $iRequest->ip_int();
+        my $iError = Img0ch::Error->new( $iKernel, $key, $ip );
+        $iError->record();
         $is_error = 1;
+        $long = $iError->get( $iApp->{__error} || 'INVALID_POST' );
     }
 
-    require Img0ch::Template;
-    my $iTemplate = Img0ch::Template->new(
-        ( $iBBS || $iKernel ),
-        {   file    => 'not_found',
-            request => $iRequest,
-            setting => $iApp->{_setting},
-        }
-    );
     my $template_parameters = {
         ( map { %{$_} } @{ $iApp->{__template_tag_error} } ),
         Archive       => $archive_path,
@@ -411,7 +405,9 @@ sub redirect_error {
         DatKByteSize  => int( $dat_bytes / 1024 ),
         IsArchived    => $archive_found,
         IsError       => $is_error,
+        IsMobile      => $iRequest->is_mobile_device(),
         IsPooled      => $pool_found,
+        KEY           => $key,
         Token1        => substr( $key, 0, 4 ),
         Token2        => substr( $key, 0, 5 ),
         LongErrorStr  => $long,
@@ -428,7 +424,15 @@ sub redirect_error {
         return $template_parameters;
     }
     else {
-        $iTemplate->param();
+        require Img0ch::Template;
+        my $iTemplate = Img0ch::Template->new(
+            ( $iBBS || $iKernel ),
+            {   file    => 'not_found',
+                request => $iRequest,
+                setting => $iApp->{_setting},
+            }
+        );
+        $iTemplate->param($template_parameters);
         $iRequest->send_http_header('text/html');
         $iTemplate->flush();
         return 0;
@@ -455,13 +459,15 @@ sub _parse_from_request {
         my $extent_param_parser = sub {
             my ( $iApp, $parameter ) = @_;
             my $extend_param = $parameter;
-            $extend_param =~ s/\A[^\!\?]*//xms;
             $iApp->{_query_with_extend_params} = $extend_param;
             my $extend_params = {};
             my $found         = 0;
             for my $chunk ( split /[&;]/xms, $extend_param ) {
-                my ( $name, $value ) = split /[\+=]/, $chunk;
-                $extend_params->{$name}
+                my ( $name, $value ) = split '=', $chunk;
+                $value ||= '';
+                $value =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack( 'H2', $1 )/gxmse;
+                $value =~ tr/+/ /;
+                $extend_params->{ $name || '' }
                     = Img0ch::Kernel::escape_html_entities($value);
                 $found++;
             }
@@ -469,7 +475,7 @@ sub _parse_from_request {
             return $found;
         };
 
-        if ( $key ne '0000000000' and @path >= 4 ) {
+        if ( $key ne '0000000000' and @path >= 3 ) {
             if ($mobile) {
                 my $query = '';
                 $raw = $path[3] || '';
@@ -480,9 +486,11 @@ sub _parse_from_request {
                 $raw = $path[2] || '';
             }
         }
-        elsif ( $bbs ne 'test' and @path >= 3 ) {
+        elsif ( $bbs ne 'test' and @path >= 2 ) {
+            my $query = '';
             $raw = $path[2] || ( $mobile ? $path[1] : '' );
-            $extent_param_parser->( $iApp, $path[1] );
+            $query = $path[1] || '';
+            $extent_param_parser->( $iApp, $query );
         }
         else {
             $raw = $path[2] || ( $mobile ? $path[1] : '' );
@@ -647,8 +655,8 @@ sub _normalize {
             $real_read_from = 1;
             $temp_range->[0] != 1 and unshift @{$temp_range}, 1;
         }
-        $real_read_to =
-            ( $temp_read_to < $res_count ) ? $temp_read_to
+        $real_read_to
+            = ( $temp_read_to < $res_count ) ? $temp_read_to
             : (
             ( $is_mobile and $temp_read_from != $temp_read_to )
             ? $real_read_from + $read_by_const
