@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Qdepot.pm 60 2006-12-31 00:29:40Z hikarin $
+# $Id: Qdepot.pm 363 2007-03-16 15:11:10Z hikarin $
 #
 
 package Img0ch::Maple::Qdepot;
@@ -33,9 +33,10 @@ sub new {
 
 sub load {
     my ( $iRepos, $path ) = @_;
-    my $repos = Depot->new( ( $path || $iRepos->{__filename} ),
-        Depot::OWRITER()|Depot::OCREAT() )
-        or $iRepos->{__kernel}->throw_exception($Depot::errmsg);
+    my $repos = Depot->new(
+        ( $path || $iRepos->{__filename} ),
+        Depot::OWRITER() | Depot::OCREAT()
+    ) or $iRepos->{__kernel}->throw_exception($Depot::errmsg);
 
     $repos->filter_fetch_key( sub   {s/\0\z//xms} );
     $repos->filter_store_key( sub   { $_ .= "\0" } );
@@ -49,7 +50,7 @@ sub save {1}
 
 sub set {
     my ( $iRepos, $key, $value ) = @_;
-    $iRepos->{__depot}->put($key, $value)
+    $iRepos->{__depot}->put( $key, $value )
         or $iRepos->{__kernel}->throw_exception($Depot::errmsg);
     return;
 }
@@ -88,7 +89,7 @@ sub iterate {
 
     $repos->iterinit();
     while ( my $key = $repos->iternext() ) {
-        my $value  = $repos->get($key)
+        my $value = $repos->get($key)
             or $iKernel->throw_exception($Depot::errmsg);
         my $status = $code_ref->( $key, \$value, @args );
         if ( $status > 0 ) {
