@@ -13,17 +13,26 @@
 # *  See the License for the specific language governing permissions and
 # *  limitations under the License.
 # */
+#
+# $Id: Config.pm 850 2007-06-23 11:39:18Z hikarin $
+#
+
 package Img0ch::Plugin::BBS::RSS::Config;
 
 use strict;
+use File::Basename qw();
+use XML::TreePP qw();
 
 sub register_hook {
-    return { render => \&build_form, };
+    return { render => \&render, };
 }
 
-sub build_form {
-    my ($zPlugin) = @_;
-    $zPlugin->add_input_text_form('max');
+sub render {
+    my ( $zPlugin, $plugin_id, $iBBS, $key ) = @_;
+    my $file = File::Basename::dirname(__FILE__) . '/layout.xml';
+    my $tree = XML::TreePP->new();
+    $zPlugin->parse_from_hash( $tree->parsefile($file) );
+    return;
 }
 
 1;
