@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Install.pm 283 2007-02-23 13:58:29Z hikarin $
+# $Id: Install.pm 900 2007-07-14 14:27:12Z hikarin $
 #
 
 package Img0ch::Plugin::Install;
@@ -26,26 +26,42 @@ sub install {
 
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::BBS::Coloring',
-            methods => {
-                name => 'bbs.write.pre',
-            },
+            methods => { name => 'bbs.write.pre', },
         }
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::BBS::HTMLTag',
+            methods => { parse => 'bbs.write.pre', },
+        }
+    );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::BBS::Icon',
             methods => {
-                parse => 'bbs.write.pre',
+                add_tag_on_bbs  => 'bbs.init',
+                add_tag_on_read => 'read.init',
+                from_bbs        => 'bbs.rewrite',
+                from_read       => 'read.rewrite',
+                save            => 'bbs.write.pre',
             },
         }
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::BBS::RSS',
-            methods => { generate_ver_10 => 'bbs.write.post', },
+            methods => {
+                generate_ver_10 => 'bbs.write.post',
+                generate_ver_20 => 'bbs.write.post',
+            },
+        }
+    );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::BBS::Random774',
+            methods => { rewrite => 'bbs.write.pre', },
         }
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::BBS::UTF8Dat',
             methods => {
+                repair => 'zeromin.recreate.subject',
                 sync   => 'bbs.write.post',
                 remove => 'zeromin.remove.thread',
             },
@@ -53,8 +69,15 @@ sub install {
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::BBS::VIP',
+            methods => { rewrite => 'bbs.write.pre', },
+        }
+    );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::BBS::VT',
             methods => {
-                rewrite => 'bbs.write.pre',
+                init   => 'bbs.init',
+                filter => 'bbs.filter',
+                create => 'bbs.write.post',
             },
         }
     );
@@ -74,11 +97,11 @@ sub install {
                 check_by_bbq  => 'bbs.filter',
                 check_by_bbx  => 'bbs.filter',
                 check_by_dsbl => 'bbs.filter',
-                by_rbl => 'bbs.filter',
-                by_spamcop => 'bbs.filter',
-                by_spamhaus => 'bbs.filter',
-                by_blitzed => 'bbs.filter',
-                by_empty => 'bbs.filter',
+                by_rbl        => 'bbs.filter',
+                by_spamcop    => 'bbs.filter',
+                by_spamhaus   => 'bbs.filter',
+                by_blitzed    => 'bbs.filter',
+                by_empty      => 'bbs.filter',
                 by_spamlookup => 'bbs.filter',
             },
         }
@@ -103,6 +126,11 @@ sub install {
             methods => { check => 'bbs.filter', },
         }
     );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Filter::NoMail',
+            methods => { check => 'bbs.filter', },
+        }
+    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Rewrite::AutoLink',
             methods => {
@@ -121,6 +149,11 @@ sub install {
             },
         }
     );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Rewrite::Movie',
+            methods => { from_mobile => 'mobile.rewrite', },
+        }
+    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Rewrite::Quotation',
             methods => {
@@ -133,48 +166,48 @@ sub install {
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Rewrite::StreamService::EbiTV',
             methods => {
-                from_bbs    => 'bbs.rewrite',
-                from_read   => 'read.rewrite',
+                from_bbs  => 'bbs.rewrite',
+                from_read => 'read.rewrite',
             },
         }
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Rewrite::StreamService::FlipClip',
             methods => {
-                from_bbs    => 'bbs.rewrite',
-                from_read   => 'read.rewrite',
+                from_bbs  => 'bbs.rewrite',
+                from_read => 'read.rewrite',
             },
         }
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Rewrite::StreamService::GoogleVideo',
             methods => {
-                from_bbs    => 'bbs.rewrite',
-                from_read   => 'read.rewrite',
+                from_bbs  => 'bbs.rewrite',
+                from_read => 'read.rewrite',
             },
         }
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Rewrite::StreamService::NicoVideo',
             methods => {
-                from_bbs    => 'bbs.rewrite',
-                from_read   => 'read.rewrite',
+                from_bbs  => 'bbs.rewrite',
+                from_read => 'read.rewrite',
             },
         }
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Rewrite::StreamService::Watchme',
             methods => {
-                from_bbs    => 'bbs.rewrite',
-                from_read   => 'read.rewrite',
+                from_bbs  => 'bbs.rewrite',
+                from_read => 'read.rewrite',
             },
         }
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Rewrite::StreamService::YouTube',
             methods => {
-                from_bbs    => 'bbs.rewrite',
-                from_read   => 'read.rewrite',
+                from_bbs  => 'bbs.rewrite',
+                from_read => 'read.rewrite',
             },
         }
     );
@@ -188,31 +221,32 @@ sub install {
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Upload::ClamAV',
-            methods => {
-                check => 'bbs.upload.pre',
-            },
+            methods => { check => 'bbs.upload.pre', },
         }
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Upload::Expires',
             methods => {
                 at_post_upload => 'bbs.upload.post',
-                at_post_write => 'bbs.write.post',
+                at_post_write  => 'bbs.write.post',
             },
         }
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Upload::MIME',
-            methods => {
-                check => 'bbs.upload.pre',
-            },
+            methods => { check => 'bbs.upload.pre', },
+        }
+    );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Upload::NoNude',
+            methods => { check => 'bbs.upload.post', },
         }
     );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Upload::Note',
             methods => {
-                save => 'bbs.upload.post',
-                from_bbs => 'bbs.rewrite',
+                save      => 'bbs.upload.post',
+                from_bbs  => 'bbs.rewrite',
                 from_read => 'read.rewrite',
             },
         }
@@ -220,21 +254,19 @@ sub install {
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Upload::Thumbnail',
             methods => {
+                repair => 'zeromin.repair.upload',
                 create => 'bbs.upload.post',
             },
         }
     );
-#    $zPlugin->install(
-#        {   package => 'Img0ch::Plugin::Upload::Remove',
-#            methods => {
-#                at_replace_res   => 'zeromin.replace.res',
-#                at_erase_res     => 'zeromin.erase.res',
-#                at_remove_file   => 'zeromin.remove.file',
-#                at_remove_thread => 'zeromin.remove.thread',
-#            },
-#        }
-#    );
-
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Upload::XCSV',
+            methods => {
+                repair   => 'zeromin.repair.upload',
+                generate => 'bbs.upload.post',
+            },
+        }
+    );
     return 1;
 }
 
