@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Action.pm 915 2007-07-19 15:02:38Z hikarin $
+# $Id: Action.pm 935 2007-07-29 12:28:04Z hikarin $
 #
 
 package Zeromin::Log::Action;
@@ -35,9 +35,20 @@ BEGIN {
 sub new {
     my ( $zClass, $iKernel ) = @_;
 
-    my $repos_path
-        = Img0ch::Maple::create_repository_subdirs( time(), 'zeromin',
-        $iKernel );
+    my $date = time();
+    my ( undef, undef, undef, $day, $month, $year ) = localtime($date);
+    $year  += 1900;
+    $month += 1;
+
+    my $path       = join '/', $year, $month, $day, 'zeromin';
+    my $repos_path = $iKernel->get_repos_path($path);
+    my $repos_dir  = $repos_path;
+    $repos_dir =~ s{/zeromin.\w+\z}{}xms;
+    if ( !-d $repos_dir ) {
+        require File::Path;
+        File::Path::mkpath($repos_dir)
+            or $iKernel->throw_io_exception($repos_dir);
+    }
     my $iRepos = $iKernel->get_repos_nocache($repos_path);
 
     bless {
