@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Metadata.pm 123 2007-01-23 13:52:09Z hikarin $
+# $Id: Metadata.pm 970 2007-08-21 14:52:15Z hikarin $
 #
 
 package Zeromin::Metadata;
@@ -22,47 +22,45 @@ package Zeromin::Metadata;
 use strict;
 use base qw(Img0ch::Metadata);
 
+BEGIN {
+    my $pkg     = __PACKAGE__;
+    my @methods = $pkg->method_info();
+
+    for my $method (@methods) {
+        my ( $name, $file, $is_global ) = @$method;
+        no strict 'refs';
+        *{"${pkg}::${name}"} = sub {
+            shift->_switch( $name, $file, @_ );
+        };
+    }
+}
+
 sub new {
     my ( $zClass, $iObject ) = @_;
     my $class = ref $iObject || '';
     my ( $zMeta, $iRepos );
 
     if ( $class eq 'Img0ch::BBS' or $class eq 'Zeromin::BBS' ) {
-        $zMeta             = $zClass->SUPER::new($iObject);
-        $zMeta->{__kernel} = $iObject->get_kernel();
+        $zMeta = $zClass->SUPER::new($iObject);
     }
-    elsif ( $class eq 'Img0ch::Maple' ) {
+    elsif ( $class eq 'Img0ch::Kernel' or $class eq 'Img0ch::Maple' ) {
         $zMeta = bless {
-            _bbs     => 'test',
-            _common => $iObject->get_repos(
-                $iObject->get_repos_path('common') ),
-            __kernel => $iObject,
+            _bbs    => 'test',
+            _kernel => $iObject,
+            _common =>
+                $iObject->get_repos( $iObject->get_repos_path('common') ),
         }, $zClass;
     }
     else {
         Img0ch::Kernel->throw_exception(
-            'Img0ch::BBS or Img0ch::Maple not given');
+            'Img0ch::BBS or Img0ch::Maple(Img0ch::Kernel) not given');
     }
 
     $zMeta;
 }
 
-sub head { shift->_switch( 'head', 'head.txt', @_ ) }
-
-sub meta { shift->_switch( 'meta', 'meta.txt', @_ ) }
-
-sub foot { shift->_switch( 'foot', 'foot.txt', @_ ) }
-
-sub main_banner { shift->_switch( 'banner.main', undef, @_ ) }
-
-sub sub_banner { shift->_switch( 'banner.sub', undef, @_ ) }
-
-sub mobile_banner { shift->_switch( 'banner.mobile', undef, @_ ) }
-
-sub thread_end { shift->_switch( 'thread', '1000.txt', @_ ) }
-
 sub remove {
-    my ( $zMeta ) = @_;
+    my ($zMeta) = @_;
     my ( $iRepos, $dir ) = ( $zMeta->{_system}, $zMeta->{_bbs} );
     $iRepos->remove("I:M.${dir}.head");
     $iRepos->remove("I:M.${dir}.meta");
@@ -80,23 +78,22 @@ sub _switch {
 }
 
 sub _save {
-    my ( $zMeta, $type, $file, $content ) = @_;
-    my ( $iReposCommon, $iReposSystem, $dir )
-        = ( $zMeta->{_common}, $zMeta->{_system},
-        ( $file ? $zMeta->{_bbs} : 'test' ) );
-    my $iKernel = $zMeta->{__kernel};
+    my ( $zMeta,   $type,         $file,         $content ) = @_;
+    my ( $iKernel, $iReposCommon, $iReposSystem, $dir )     = (
+        $zMeta->{_kernel}, $zMeta->{_common}, $zMeta->{_system},
+        ( $file ? $zMeta->{_bbs} : 'test' )
+    );
 
     require Zeromin::Plugin;
     my $zPlugin = Zeromin::Plugin->new($iKernel);
-    $zPlugin->do( "zeromin.update.${type}",
-        $zMeta, [ $zMeta->{_bbs}, $content ] );
+    $zPlugin->do( "zeromin.update.${type}", $zMeta,
+        [ $zMeta->{_bbs}, $content ] );
 
     if ($file) {
-        my $iKernel = $zMeta->{__kernel};
-        my $base    = $iKernel->get_config()->get('BBSPath');
-        my $path    = join '/', $base, $dir, $file;
+        my $base = $iKernel->get_config()->get('BBSPath');
+        my $path = join '/', $base, $dir, $file;
         local ( $!, *FH );
-        open *FH, '>', $path
+        open *FH, ">${path}"    ## no critic
             or $iKernel->throw_io_exception($path);
         print {*FH} ${$content}
             or $iKernel->throw_io_exception($path);
