@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Setting.pm 363 2007-03-16 15:11:10Z hikarin $
+# $Id: Setting.pm 958 2007-08-09 12:26:17Z hikarin $
 #
 
 package Zeromin::Setting;
@@ -49,14 +49,15 @@ my $stringify = {
 
 sub new {
     my ( $zClass, $iObject ) = @_;
-    my $iBBS = ( ref $iObject || '' ) eq 'Zeromin::BBS'
+    my $iBBS
+        = ( ref $iObject || '' ) eq 'Zeromin::BBS'
         ? $iObject->parent()
         : $iObject;
-    my $iKernel  = $iBBS->get_kernel();
+
     my $zSetting = $zClass->SUPER::new($iBBS);
+    my $iKernel  = $zSetting->{_kernel};
     $zSetting->{__bbs}      = $iBBS;
     $zSetting->{__setting}  = {};
-    $zSetting->{__kernel}   = $iKernel;
     $zSetting->{__encoding} = $iKernel->get_encoding(1);
 
     my $base = join '/', $iKernel->get_config()->get('SystemPath'),
@@ -92,11 +93,11 @@ sub gets {
     $ret;
 }
 
-sub get_normalized {
-    my ( $zSetting, $key, $unijp ) = @_;
+sub _get_normalized {
+    my ( $get_method_type, $zSetting, $key, $unijp ) = @_;
     my $info  = $zSetting->{__info};
     my $hash  = $info->{$key} or return '';
-    my $value = $zSetting->get($key);
+    my $value = $zSetting->$get_method_type($key);
 
     if ( $unijp and $hash->{type} eq 'string' ) {
         $value = $unijp->set( $value, $zSetting->{__encoding} )->get();
@@ -104,6 +105,10 @@ sub get_normalized {
     return $value;
 }
 
+sub get_normalized { _get_normalized( 'get', @_ ) }
+
+sub get_normalized_utf8 { _get_normalized( 'get_utf8', @_ ) }
+
 sub get_default { shift->_get( shift, 'default' ) }
 
 sub get_order { shift->_get( shift, 'order' ) }
@@ -155,8 +160,7 @@ sub merge {
         next if $key eq 'BBS_TITLE' or $key eq 'BBS_MODE';
         my $hash = $info->{$key};
         $hash or next;
-        my $value = $value || $hash->{default};
-        $zSetting->set( $key, $value );
+        $zSetting->{__setting}->{$key} = $value || $hash->{default};
     }
 
     1;
@@ -212,6 +216,7 @@ sub save {
         $cache->{$key} = $value;
         $iReposSystem->set( "I:S.${bbs}.${key}", $value );
         $iReposCommon->set( "I:S.${i}",          $key );
+        $iReposSystem->remove($key);
         $iReposCommon->remove("I:S.${bbs}.${key}");
         $i++;
     }
@@ -222,7 +227,7 @@ sub save {
     $no_disk ||= 0;
     my $iBBS = $zSetting->{__bbs};
     if ( !$no_disk ) {
-        my $iKernel = $zSetting->{__kernel};
+        my $iKernel = $zSetting->{_kernel};
         my $dir     = $iBBS->get_name();
         $path ||= $zSetting->path();
         local ( $!, *FH );
@@ -265,7 +270,7 @@ sub remove {
         );
         $iRepos->save();
     }
-    unlink $path or $zSetting->{__kernel}->throw_io_exception($path);
+    unlink $path or $zSetting->{_kernel}->throw_io_exception($path);
 
     1;
 }
